@@ -7,9 +7,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       observed<-data[,2]
       scores.a<-combn(observed,MT/2)
       mean.a<-numeric(ncol(scores.a))
@@ -50,9 +47,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       N<-c(rep("A",MT/2),rep("B",MT/2))
       assignment<-matrix(0,ncol=MT)
       assignment<-rbind(sample(N,MT,replace=FALSE))
@@ -134,9 +128,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     observed1<-rbind(observed.a,observed.b)
     observed2<-rbind(observed.b,observed.a)
     scores.a<-numeric()
@@ -181,9 +172,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       index<-1:MT
       index.a<-matrix(combn(index,(MT/2)),ncol=quantityCRD)
       index.b<-matrix(index.a[,ncol(index.a):1],ncol=quantityCRD)
@@ -280,9 +268,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       N<-c(rep(0,MT/2),rep(1,MT/2))
       assignment<-matrix(0,ncol=MT)
       assignment<-rbind(rep(c(0,1),MT/2))
@@ -390,9 +375,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index.a<-limit:(MT-limit)
     scores.a<-list()
     for(it in 1:quantity){
@@ -439,9 +421,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index1<-1:(MT-3*limit+1)
     index2<-rev(index1)
     index.a<-numeric()
@@ -569,9 +548,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index1<-1:(MT-4*limit+1)
     index2<-rev(cumsum(index1))
     index.a1<-numeric()
@@ -889,9 +865,6 @@ distribution.systematic<-function(design,statistic,save="no",limit,data=read.tab
     if(save=="yes"){
       fileSAVE<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      fileSAVE<-fileName
-    }
     if(save=="yes"|save=="check"){
       write.table(distribution,file=fileSAVE,col.names=FALSE,row.names=FALSE,append=FALSE)
       return(distribution)
